@@ -73,6 +73,35 @@ class EnvDefault(argparse.Action):
                             default=default, **kwargs)
 
 
+class DbParser(argparse.ArgumentParser):
+
+    def __init__(self, parser):
+        self.parser = parser
+        group = self.parser.add_argument_group(
+            'Database arguments',
+            'Arguments related to administering the database')
+
+        Add = EnvDefault.add
+        Add(group, "dbhost", HOSTNAME,
+            help="Hostname of the OMERO database server")
+        # No default dbname to prevent inadvertent upgrading of databases
+        Add(group, "dbname", None,
+            help="Name of the OMERO database")
+        Add(group, "dbuser", "omero",
+            help="Username for connecting to the OMERO database")
+        Add(group, "dbpass", "omero",
+            help="Password for connecting to the OMERO database")
+        # TODO Admin credentials: dbauser, dbapass
+
+        Add(group, "omerosql", "omero.sql",
+            help="OMERO database SQL file")
+        Add(group, "rootpass", "omero",
+            help="OMERO admin password")
+
+    def __getattr__(self, key):
+        return getattr(self.parser, key)
+
+
 class JenkinsParser(argparse.ArgumentParser):
 
     def __init__(self, parser):
@@ -82,30 +111,42 @@ class JenkinsParser(argparse.ArgumentParser):
             'Arguments related to the Jenkins instance')
 
         Add = EnvDefault.add
-        Add(group, "hudson", "hudson.openmicroscopy.org.uk",
-            help="Base url of the Jenkins instance")
+        Add(group, "ci", "ci.openmicroscopy.org",
+            help="Base url of the continuous integration server")
         Add(group, "branch", "OMERO-trunk",
             help="Name of the Jenkins job containing the artifacts")
         Add(group, "build",
-            "http://%(hudson)s/job/%(branch)s/lastSuccessfulBuild/",
+            "http://%(ci)s/job/%(branch)s/lastSuccessfulBuild/",
             help="Full url of the Jenkins build containing the artifacts")
+        Add(group, "labels", "ICE=3.5",
+            help="Comma separated list of labels for matrix builds")
 
-        # UNZIP TOOLS
-        if WINDOWS:
-            unzip = "C:\\Program Files (x86)\\7-Zip\\7z.exe"
-            unzipargs = "x"
-        else:
-            unzip = "unzip"
-            unzipargs = ""
+    def __getattr__(self, key):
+        return getattr(self.parser, key)
 
-        Add(group, "unzip", unzip,
-            help="Program to use to unzip the Jenkins artifact")
-        Add(group, "unzipargs", unzipargs,
-            help="Arguments to pass while unzipping the Jenkins artifact")
+
+class FileUtilsParser(argparse.ArgumentParser):
+
+    def __init__(self, parser):
+        self.parser = parser
+        group = self.parser.add_argument_group(
+            'Remote and local file handling parameters',
+            'Additional arguments for downloading or unzipped files')
+
+        Add = EnvDefault.add
         Add(group, "unzipdir", "",
-            help="Directory to unzip the Jenkins artifact to")
+            help="Unzip archives into this directory")
         group.add_argument("--skipunzip", action="store_true",
-                           help="Skip the artifact unzipping")
+                           help="Don't unzip archives")
+        # Choices from fileutils.get_as_local_path
+        Add(group, "overwrite", "keep",
+            choices=["error", "backup", "keep"],
+            help="Whether to overwrite or keep existing files (default error)")
+
+        Add(group, "httpuser", None,
+            help="Username for HTTP authentication")
+        Add(group, "httppassword", None,
+            help="Password for HTTP authentication")
 
     def __getattr__(self, key):
         return getattr(self.parser, key)
